/*=============================================================================
    Copyright (c) 2001-2011 Joel de Guzman
    Copyright (c) 2001-2011 Hartmut Kaiser
    http://spirit.sourceforge.net/

    Distributed under the Boost Software License, Version 1.0. (See accompanying
    file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
=============================================================================*/
#ifndef BOOST_SPIRIT_INCLUDE_PHOENIX_CORE
#define BOOST_SPIRIT_INCLUDE_PHOENIX_CORE

#ifndef BOOST_SPIRIT_USE_PHOENIX_V3
#define BOOST_PHOENIX_DEFINE_CUSTOM_TERMINAL(A,B,C,D)
#include <boost/spirit/home/phoenix/core.hpp>
#else
#include <boost/phoenix/core.hpp>
#endif

#endif
